@@ -162,11 +162,11 @@ use Carp;
 use Fcntl;
 use Symbol;
 use Exporter;
-use Scalar::Util;
+use Scalar::Util ();
 use vars qw( $VERSION @ISA @EXPORT_OK %EXPORT_TAGS );
 
 BEGIN {
-    $VERSION   = '0.94_01';
+    $VERSION   = '0.94_02';
     @ISA       = qw( Exporter );
     @EXPORT_OK = qw(
       check
